@@ -1,5 +1,9 @@
 package Devel::WatchVars;
 
+=encoding utf8
+
+=cut
+
 use utf8;
 use strict;
 use warnings;
@@ -12,7 +16,7 @@ use namespace::clean;
 
 ###########################################################
 
-our $VERSION = v1.0.2;
+our $VERSION = v1.0.3;
 
 use Exporter qw(import);
 our @EXPORT = qw(watch unwatch);
@@ -181,6 +185,19 @@ the C<unwatch> function is implemented using an internal C<untie>.
 See the example scripts in the F<examples> subdirectory of 
 this module's source distribution.
 
+=head1 ENVIRONMENT
+
+=over
+
+=item DEVEL_WATCHVARS_VERBOSE
+
+Normally, the traces include only a L<shortmess|Carp/shortmess> at the end,
+no matter what you've may have set the value of C<$Carp::Verbose> to.
+But if the environment variable C<DEVEL_WATCHVARS_VERBOSE> has a true
+value, a full L<longmess|Carp/shortmess> will be used instead.
+
+=back
+
 =head1 DIAGNOSTICS
 
 =over
@@ -224,6 +241,12 @@ cheating by calling the functions without prototypes being checked.
 
 =back
 
+=head1 TODO
+
+Devise a curried subclassing mechanism.
+
+Add watching entire aggregate arrays and hashes I<en masse>.
+
 =head1 SEE ALSO
 
 =over
